@@ -1,27 +1,15 @@
-impute.rfsrc <- function(formula,
-                         data,
-                         ntree = 500,
-                         mtry = NULL,
-                         xvar.wt = NULL,
-                         nodesize = 1,
-                         splitrule = NULL,
-                         nsplit = 10,
-                         
-                         na.action = c("na.impute"),
-                         
-                          
-                         nimpute = 2,
-                         mf.q, blocks,
-                         always.use = NULL, 
-                         max.iter = 10,
-                         eps = 0.01,
-                         verbose = TRUE, 
-                         do.trace = FALSE,
+impute.rfsrc <- function(formula, data,
+                         ntree = 500, nodesize = 1, nsplit = 10,
+                         nimpute = 2, fast = FALSE, blocks,                         
+                         mf.q, max.iter = 10, eps = 0.01,
+                         ytry = NULL, always.use = NULL, verbose = TRUE, 
                          ...)
 {
-  ## get any hidden options
-  user.option <- list(...)
-  ytry <- is.hidden.ytry(user.option)
+  ##--------------------------------------------------------------
+  ##
+  ## preliminary checks to make sure impute makes sense
+  ##
+  ##--------------------------------------------------------------
   ## terminate if there is no data
   if (missing(data)) {
     stop("data is missing")
@@ -32,6 +20,26 @@ impute.rfsrc <- function(formula,
   if (!any(which.na) || all(which.na)) {
     return(invisible(data))
   }
+  ##--------------------------------------------------------------
+  ##
+  ## extract additional options specified by user
+  ## we lock this down - here are the options we allow
+  ##
+  ##--------------------------------------------------------------
+  ## list of allowed parameters
+  rfnames <- c("mtry",
+               "splitrule",
+               "bootstrap",
+               "sampsize",
+               "samptype")
+  ## get the permissible hidden options
+  dots <- list(...)
+  dots <- dots[names(dots) %in% rfnames]
+  ##--------------------------------------------------------------
+  ##
+  ## process the data
+  ##
+  ##--------------------------------------------------------------
   ## acquire various dimensions/information
   p <- ncol(data)
   n <- nrow(data)
@@ -48,47 +56,57 @@ impute.rfsrc <- function(formula,
   n <- nrow(data)
   ## extract the variable names to retain consistency of their order
   all.var.names <- colnames(data)
+  ##--------------------------------------------------------------
+  ##
+  ## set values needed for the impute call
+  ##
+  ##--------------------------------------------------------------
   ## mforest details
   if (missing(mf.q)) {
     mforest <- FALSE
   }
-    else {
-      mforest <- TRUE
-    }
+  else {
+    mforest <- TRUE
+  }
   ## set the number of blocks used to subdivide the data
   ## hence subdivide the problem into more manageable pieces
   if (!missing(blocks)) {
     blocks <- cv.folds(nrow(data), max(1, blocks))
   }
-    else {
-      blocks <- list(1:nrow(data))
-    }
-  ## generic impute call
+  else {
+    blocks <- list(1:nrow(data))
+  }
+  ##--------------------------------------------------------------
+  ##
+  ## METHOD 1: default impute call
+  ##
+  ##--------------------------------------------------------------
   if (!mforest) {
     ## if the formula is missing we are implementing unsupervised forests
     if (missing(formula)) {
       if (is.null(ytry)) {
         ytry <- min(p - 1, max(25, ceiling(sqrt(p))))
       }
-      formula <- as.formula(paste("Unsupervised(", ytry, ") ~ ."))
+      dots$formula <- as.formula(paste("Unsupervised(", ytry, ") ~ ."))
+      ##splitrule not permissible with unsupervised forests? TBD TBD
+      dots$splitrule <- NULL
+    }
+    else {
+      dots$formula <- formula
     }
     ## loop over data blocks
     nullBlocks <- lapply(blocks, function(blk) {
       ## assign the blocked data
       dta <- data[blk,, drop = FALSE]
       ## make the generic impute call
-      retO <- tryCatch({generic.impute.rfsrc(formula = formula,
-                                             data = dta,
-                                             ntree = ntree,
-                                             nimpute = nimpute,
-                                             mtry = mtry,
-                                             nodesize = nodesize,
-                                             splitrule = splitrule,
-                                             nsplit = nsplit,
-                                             na.action = na.action,
-                                             xvar.wt = xvar.wt,
-                                             do.trace = do.trace)}, error = function(e) {NULL})
-      ## if the impute object is non-null proceed ahead
+      retO <- tryCatch({do.call("generic.impute.rfsrc",
+                      c(list(data = dta,
+                             ntree = ntree,
+                             nodesize = nodesize,
+                             nsplit = nsplit,
+                             nimpute = nimpute,
+                             fast = fast), dots))}, error = function(e) {NULL})
+      ## proceed if the impute object is non-null
       if (!is.null(retO)) {
         ## overlay the imputed data
         ## we retain the same column order
@@ -109,7 +127,11 @@ impute.rfsrc <- function(formula,
     })
     rm(nullBlocks)
   }
-  ## mforest call
+  ##--------------------------------------------------------------
+  ##
+  ## METHOD 2: mforest
+  ##
+  ##--------------------------------------------------------------
   if (mforest) {
     ## identify which variables have missing data
     ## store the information as a convenient list
@@ -142,14 +164,17 @@ impute.rfsrc <- function(formula,
     }
     ## convert mf.q to K-fold selection
     K <- max(1 / mf.q, 2)
-    ## quick and rough impute
+    ## quick and *rough* impute
     ## uncomment the following line for a better initial estimate
-    data <- generic.impute.rfsrc(data = data,
-                                 nimpute = 3,
-                                 ntree = 250,
-                                 mtry = mtry,
-                                 nodesize = nodesize,
-                                 nsplit = nsplit)$data
+    dots.rough <- dots
+    dots.rough$mtry <- dots.rough$splitrule <- NULL##splitrule not permissible with unsupervised forests? TBD TBD
+    data <- do.call("generic.impute.rfsrc",
+                      c(list(data = data,
+                             ntree = 250,
+                             nodesize = nodesize,
+                             nsplit = nsplit,
+                             nimpute = 3,
+                             fast = fast), dots.rough))$data
     ###############################################################
     ## main loop: data blocks/groups of variables
     ## we use lapply to avoid for-looping
@@ -180,7 +205,7 @@ impute.rfsrc <- function(formula,
         nullObj <- lapply(var.grp, function(grp) {
           ## multivariate formula
           ynames <- unique(c(var.names[grp], all.var.names[always.use]))
-          f <- as.formula(paste("Multivar(", paste(ynames, collapse = ","), paste(") ~ ."), sep = ""))
+          dots$formula <- as.formula(paste("Multivar(", paste(ynames, collapse = ","), paste(") ~ ."), sep = ""))
           ## reset the chosen y missing data back to NA
           dta <- data[blk,, drop = FALSE]
           dta[, ynames] <- lapply(ynames, function(nn) {
@@ -191,15 +216,13 @@ impute.rfsrc <- function(formula,
           ## multivariate missForest call
           ## first column of returned object contains the imputed "y-values" which is what we want
           ## we do not use the other imputed data: this is very important
-          retO <- tryCatch({generic.impute.rfsrc(f,
-                                                 dta,
-                                                 ntree = ntree,
-                                                 nimpute = 1,
-                                                 na.action =  na.action,
-                                                 mtry = mtry,
-                                                 nodesize = nodesize,
-                                                 splitrule = splitrule,
-                                                 nsplit = nsplit)}, error = function(e) {NULL})
+          retO <- tryCatch({do.call("generic.impute.rfsrc",
+                                    c(list(data = dta,
+                                           ntree = ntree,
+                                           nodesize = nodesize,
+                                           nsplit = nsplit,
+                                           nimpute = 1,
+                                           fast = fast), dots))}, error = function(e) {NULL})
           ## confirm that the impute object is non-null in order to proceed
           if (!is.null(retO)) {
             ## overlay the imputed data
@@ -235,7 +258,9 @@ impute.rfsrc <- function(formula,
           }
       }), na.rm = TRUE)
       if (verbose) {
-        cat("         >> ", diff.new.err, diff.err - diff.new.err, "\n")
+        err <- paste("err = " , format(diff.new.err, digits = 3), sep = "")
+        drp <- paste("drop = ", format(diff.err - diff.new.err, digits = 3), sep = "")
+        cat("         >> ", err, ", ", drp, "\n")
       }
       check <<- ((diff.err - diff.new.err) >= eps)
       diff.err <<- diff.new.err
@@ -244,9 +269,11 @@ impute.rfsrc <- function(formula,
       NULL
     })
   }
-  ## #############################################################
+  ##--------------------------------------------------------------
+  ##
   ## return the imputed data
-  ## #############################################################
+  ##
+  ##--------------------------------------------------------------
   invisible(data)
 }
 impute <- impute.rfsrc
